package Bric::Biz::AssetType;
###############################################################################

=head1 NAME

Bric::Biz::AssetType - Deprecated; use Bric::Biz::ElementType instead

=head1 VERSION

$LastChangedRevision$

=cut

require Bric; our $VERSION = Bric->VERSION;

=head1 DATE

$LastChangedDate: 2006-08-07 22:45:13 +0200 (Mon, 07 Aug 2006) $

=head1 DESCRIPTION

The functionality of this class has been moved to
L<Bric::Biz::ElementType|Bric::Biz::ElementType>. Please use that class,
instead.

=cut

use base 'Bric::Biz::ElementType';
use Bric::Biz::AssetType::Parts::Data;

1;
__END__
